@@ -48,6 +48,9 @@
 #include <linux/workqueue.h>
 #include <linux/vmalloc.h>
 
+#if LINUX_VERSION_CODE > KERNEL_VERSION(4,11,0)
+#include <linux/sched/signal.h>
+#endif
 
 #if !defined(CONFIG_X86) && !defined(CONFIG_X86_64)
 #error "this module is for x86 or x86_64 architectures only"
@@ -119,9 +122,13 @@ static cpumask_t cpumasks[NR_CPUS];
  */
 #include <asm/dma-mapping.h>
 
+#ifndef ___GFP_RETRY_MAYFAIL
+#define ___GFP_RETRY_MAYFAIL __GFP_REPEAT
+#endif
+
 #define PCI_DMA_ALLOC_COHERENT(pci_dev,size,dma_handle)			\
 	dma_alloc_coherent(&pci_dev->dev,size,dma_handle,		\
-			   GFP_KERNEL | __GFP_REPEAT)
+			   GFP_KERNEL | ___GFP_RETRY_MAYFAIL)
 #define PCI_DMA_FREE_COHERENT(pci_dev,size,cpu_addr,dma_handle)		\
 	dma_free_coherent(&pci_dev->dev,size,cpu_addr,dma_handle)
 #define PCI_DMA_MAP_SINGLE(pci_dev,addr,size,direction)		\
